#!/bin/sh

# Script for deleting Firefox profiles for all users
# Must be executed with root privileges

main() {
    if [[ $EUID -ne 0 ]]; then
        echo "This script must be executed with root privileges" 
        exit 1
    fi

    local user_dirs=$(dscacheutil -q user | grep -A 2 -B 2 -e uid:\ 5'[0-9][0-9]' | grep "dir: " | cut -f2 -d' ')
    echo "User dirs:"
    echo "$user_dirs"

    for user_dir_path in ${user_dirs[*]};
    do
        if [ ! -d "$user_dir_path/Library/Application Support/Firefox" ]; then
            echo "There is no Firefox directory in $user_dir_path/Library/Application Support"
            echo ""
            continue
        fi

        read -p "Are you sure to backup Fifefox profile data from $user_dir_path/Library/Application Support/Firefox to $user_dir_path/backups and delete it? [Y/N]: " REPLY
        echo
        if [[ $REPLY =~ ^[Yy]$ ]];
        then
            echo "Create $user_dir_path/backups"
            mkdir "$user_dir_path/backups"
            echo "Backup Firefox profile data to $user_dir_path/backups"
            cp -rvf "$user_dir_path/Library/Application Support/Firefox/profiles.ini" "$user_dir_path/backups"
            cp -rvf "$user_dir_path/Library/Application Support/Firefox/Profiles" "$user_dir_path/backups"
            echo "Deleting all profiles data in $user_dir_path/Library/Application Support/Firefox"
            rm -irvf "$user_dir_path/Library/Application Support/Firefox/Profiles/"* 
            rm -irvf "$user_dir_path/Library/Application Support/Firefox/profiles.ini"
        fi
    done
}

main
